@@ -1,4 +1,5 @@
 <?php
+
 /***************************************************************************
  * Class name   : reserv
  * description  : Function used in the distribution reservation screen.
@@ -21,6 +22,7 @@ Class reserv extends Validation {
     private $test_send = FALSE;
     private $immd_send = FALSE;
     private $rsrv_send = FALSE;
+    private $temporal_charset = "UTF-8";
 
     /************************************************************************
      * method name : __construct()
@@ -58,12 +60,24 @@ Class reserv extends Validation {
     public function changeMimeencode($word)
     {
 
-        /* Encode a string */
-        $en_word = mb_convert_encoding($word, $this->to_char, $this->from_char);
+        /* Check internal encoding */
+        $default_internal_encode = mb_internal_encoding();
+        if ($default_internal_encode !== $this->temporal_charset) {
+            /* Change internal encoding 'UTF-8' temporally */
+            mb_internal_encoding($this->temporal_charset);
+        }
 
-        /* Mime encoded string */
+        /* Unify input encoding of the string as UTF-8 */
+        $en_word = mb_convert_encoding($word, $this->temporal_charset, $this->from_char);
+
+        /* Mime encode with internal encoding 'UTF-8'
+         * Note: charset of $en_word must be same as the internal encoding.
+         */
         $mime_word = mb_encode_mimeheader($en_word, $this->to_char, $this->encoding);
 
+        /* Reset default internal encode */
+        mb_internal_encoding($default_internal_encode);
+
         return $mime_word;
     }
 
@@ -140,7 +154,7 @@ Class reserv extends Validation {
         $mailinfo = "To: $to\r\n";
         $mailinfo .= "From: $from\r\n";
         if (isset($this->reply_to)) {
-             $mailinfo .= "Reply_to: $this->reply_to\r\n";
+             $mailinfo .= "Reply-to: $this->reply_to\r\n";
         }
         $mailinfo .= "Subject: $subject\r\n";
         $mailinfo .= "Content-Type: text/plain; charset=ISO-2022-JP\r\n" .
@@ -171,7 +185,7 @@ Class reserv extends Validation {
         $mailinfo = "To: $to\r\n";
         $mailinfo .= "From: $from\r\n";
         if (isset($this->reply_to)) {
-             $mailinfo .= "Reply_to: $this->reply_to\r\n";
+             $mailinfo .= "Reply-to: $this->reply_to\r\n";
         }
         $mailinfo .= "Subject: $this->subject\r\n";
         $mailinfo .= "Content-Type: text/plain; charset=ISO-2022-JP\r\n" .
